docs.rs failed to build mlir-testutils-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
mlir-testutils
Utilities for writing tests in crates that use melior.
For the utilities that assert equality between two things you can enable the similar-asserts feature.
Enabling this feature makes the assertions use similar-asserts
instead of the standard assert_eq macro.